@@ -1,7 +1,6 @@
 from jaaql.exceptions.http_status_exception import HttpStatusException
 from jaaql.interpreter.interpret_jaaql import InterpretJAAQL
-from jaaql.constants import ENCODING__utf, KEY__tenant_name, KEY__enc_symmetric_key
-from jaaql.mvc.queries import QUERY__load_tenant_symmetric_keys
+from jaaql.constants import ENCODING__utf, VAULT_KEY__super_db_credentials
 from typing import Union
 import jaaql.utilities.crypt_utils as crypt_utils
 from jaaql.db.db_pg_interface import DBPGInterface
@@ -14,7 +13,7 @@ ERR__missing_encrypt_parameter = "Encrypted parameter is not found '%s'"
 ERR__duplicated_encryption_salt = "Duplicated value in encryption_salts list"
 ERR__expected_single_row = "Expected single row response but received '%d' rows"
 ERR__unsupported_interface = "Unsupported interface '%s'. We only support %s"
-
+ERR__schema_invalid = "Schema invalid!"
 
 KEY_CONFIG__db = "DATABASE"
 KEY_CONFIG__interface = "interface"
@@ -167,7 +166,7 @@ def execute_supplied_statements(db_interface, queries: Union[str, list],
     return data
 
 
-def load_tenant_symmetric_keys(connection: DBInterface, crypt_key: bytes):
-    keys = execute_supplied_statement(connection, QUERY__load_tenant_symmetric_keys, as_objects=True,
-                                      encryption_key=crypt_key, decrypt_columns=[KEY__enc_symmetric_key])
-    return {row[KEY__tenant_name]: row[KEY__enc_symmetric_key].encode() for row in keys}
+def create_interface_for_db(vault, config, user_id: str, database: str, sub_role: str = None):
+    jaaql_uri = vault.get_obj(VAULT_KEY__super_db_credentials)
+    address, port, _, username, password = DBInterface.fracture_uri(jaaql_uri)
+    return create_interface(config, address, port, database, username, password=password, role=user_id, sub_role=sub_role)
